@@ -871,12 +871,12 @@ if (genre=="")
 QSqlQuery query(db);
 QString sq="INSERT INTO tracks (path, title, artist, genre, album, year) "
            "VALUES ("
-            "'"+metaInformationResolver->currentSource().fileName()+
-            "','"+title+
-            "','"+artist+
-            "','"+genre+
-            "','"+album+
-            "','"+year+"')";
+            "'"+metaInformationResolver->currentSource().fileName().replace("'","''")+
+            "','"+title.replace("'","''")+
+            "','"+artist.replace("'","''")+
+            "','"+genre.replace("'","''")+
+            "','"+album.replace("'","''")+
+            "','"+year.replace("'","''")+"')";
 
 query.exec(sq);
 
