@@ -63,9 +63,12 @@ public:
     QString track_title,track_artist,track_album;
     QString eq_name;
     QMenu *eq_menu;
+    qreal vol_change;
 signals:
     Q_SCRIPTABLE void track_change(QString );
 public slots:
+    void m3uForDir();
+    void set_list();
     void rem_eq();
     void eq_fn_click();
     void save_eq_d();
@@ -124,7 +127,7 @@ public slots:
     void replyFinished2(QNetworkReply*);
     void replyFinished3(QNetworkReply*);
     void kbdhelp();
-    void orientationChanged();
+    void volumeChanged (qreal);
 protected:
   void keyPressEvent(QKeyEvent* event);
   bool eventFilter(QObject *obj, QEvent *event);
