@@ -31,6 +31,10 @@ QFont h(fnt);
 ui.fontComboBox->setCurrentFont(h);
 ui.spinBox->setValue(size);
 
+size=get_setting("volume_change").toLong();
+if (size==0)size=10;
+ui.spinBox_2->setValue(size);
+
 ui.lineEdit->setText(filter);
 ui.lineEdit_2->setText(get_setting("last_login"));
 ui.lineEdit_3->setText(get_setting("last_password"));
@@ -38,6 +42,7 @@ ui.comboBox_2->setCurrentIndex(get_setting("internet_load").toLong());
 ui.comboBox_3->setCurrentIndex(get_setting("head_disconnect").toLong());
 ui.comboBox_4->setCurrentIndex(get_setting("head_connect").toLong());
 ui.comboBox_5->setCurrentIndex(get_setting("start_action").toLong());
+ui.comboBox_6->setCurrentIndex(get_setting("volume_behaviour").toLong());
 
 
 }
@@ -53,6 +58,8 @@ void options::save(){
    set_setting("head_disconnect",QString("%1").arg(ui.comboBox_3->currentIndex()));
    set_setting("head_connect",QString("%1").arg(ui.comboBox_4->currentIndex()));
    set_setting("start_action",QString("%1").arg(ui.comboBox_5->currentIndex()));
+   set_setting("volume_behaviour",QString("%1").arg(ui.comboBox_6->currentIndex()));
+   set_setting("volume_change",QString("%1").arg(ui.spinBox_2->value()));
    this->accept();
    this->close();
 }
